@@ -39,13 +39,14 @@
 // The very first function to call
 session_start();
 
-$expexted_version = "1.3.5";
+$expected_version = "1.3.6p1";
 
 // Session check
-if ( !array_key_exists('backend_version', $_SESSION ) || $_SESSION['backend_version'] !=  $expexted_version ) {
+if ( !array_key_exists('backend_version', $_SESSION ) || $_SESSION['backend_version'] !=  $expected_version ) {
 	session_destroy();
 	session_start();
-	$_SESSION['version'] = $expexted_version;
+	$_SESSION['version'] = $expected_version;
+	print "<h1>Frontend - Backend version missmatch!</h1>\n";
 }
 
 include ("conf.php");
@@ -496,7 +497,7 @@ ReportLog("Bookmark: Set $_varname");
 		} else {
 			// Verify new tab
 			if ( !is_numeric($_tab) || ( ($_tab > count($TabList)) || ($_tab < 0) ) ) {
-				SetMessage('warning', "Tab '$_tab' not available. Set default tab to " . $TabList[0]);
+				SetMessage('warning', "Requested Tab not available. Set default tab to " . $TabList[0]);
 				$_tab = 0;
 			}
 			$_tab = (int)$_tab;
@@ -687,8 +688,12 @@ switch ($label) {
 		Process_stat_tab($tab_changed, $profile_changed);
 		break;
 	case "Plugins":
-		if ( $tab_changed || !array_key_exists('sub_tab', $_SESSION ))
-			$_SESSION['sub_tab'] = 0;
+		if ( $tab_changed || !array_key_exists('sub_tab', $_SESSION )) {
+			if(isset($_GET['sub_tab']))
+				$_SESSION['sub_tab'] = intval($_GET['sub_tab']);
+			else
+				$_SESSION['sub_tab'] = 0;
+		}
  		$plugins  = GetPlugins ();
 		if ($_SESSION['sub_tab'] > count($plugins)) {
 			SetMessage('error', "Plugin number out of range!");
