@@ -52,7 +52,7 @@ foreach ($_SESSION['rrdgraph_getparams'] as $getparam => $dummy ) {
 		$opts[$getparam] = $_GET[$getparam];
 	}
 }
-$arglist = split(' ', urldecode($_GET['arg']));
+$arglist = explode(' ', urldecode($_GET['arg']));
 $opts['.silent'] = 1;
 foreach ( $arglist as $arg ) {
 	$opts['arg'][] = $arg;
