@@ -28,11 +28,13 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: install.pl 67 2010-09-09 05:56:05Z haag $
+#  $Id: install.pl 53 2012-01-23 16:36:02Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 53 $
+#
+#  Last changed date:    $Date: 2012-01-23 17:36:02 +0100 (Mon, 23 Jan 2012) $
 
 require 5.6.0;
 
@@ -44,6 +46,7 @@ use strict;
 use NfSen;
 use NfProfile;
 use NfSenRRD;
+use Nfsync;
 use Nfsources;
 
 # from installer-items - helper modules
@@ -52,8 +55,8 @@ use File::Copy;
 use File::Path;
 use RRDconvertv1;
 
-my $VERSION = '$Id: install.pl 67 2010-09-09 05:56:05Z haag $';
-my $nfsen_version = "1.3.5";
+my $VERSION = '$Id: install.pl 53 2012-01-23 16:36:02Z peter $';
+my $nfsen_version = "1.3.6p1";
 
 my @ProfileTag = ( 
 	"# \n",
@@ -200,16 +203,18 @@ sub VerifyConfig {
 	}
 
 	my @out = `$NfConf::PREFIX/nfdump -V`;
-	if ( scalar @out != 2 ) {
+	if ( scalar @out <= 0 ) {
 		die "Error getting nfdump version";
 	}
 	chomp $out[0];
-	my ($major, $minor) = $out[0] =~ /Version:\s(\d)\.(\d)\s/;
+	my ($major, $minor) = $out[0] =~ /Version:\s(\d)\.(\d+)/;
 	if ( defined $major && defined $minor) {
 		if ( $major >= 1 && $minor >= 6 ) {
 			print "Found $out[0]\n";
+		} elsif ( $out[0] =~ /Version:\s1.5.8-\d+-NSEL/ )  {
+			print "Found nfdump NSEL\n";
 		} else {
-			print "out[0]\n";
+			print "$out[0]\n";
 			die "Nfdump version not compatible with current NfSen version.\n";
 		}
 	} 
@@ -466,6 +471,7 @@ sub UpgradeProfiles {
 		return;
 	}
 
+	Nfsync::seminit();
 	$CopyRecursive::UID 	 = $nfsen_uid;
 	$CopyRecursive::GID 	 = $www_gid;
 	$CopyRecursive::MODE 	 = 0644;
@@ -547,7 +553,7 @@ sub UpgradeProfiles {
 				if( ! -f "$NfConf::PROFILEDATADIR/$profilepath/$channel/.nfstat") { 
 					# no shadow profile, but missing channel stat
 					print "Rebuilding profile stats for '$profilegroup/$profilename'\n";
-					NfProfile::DoRebuild(\%profileinfo, $profilename, $profilegroup, $profilepath, 1);
+					NfProfile::DoRebuild(\%profileinfo, $profilename, $profilegroup, $profilepath, 1, 0);
 					NfProfile::WriteProfile(\%profileinfo);
 				}
 				# make sure it's own by nfsen_uid after the rebuild
@@ -562,6 +568,7 @@ sub UpgradeProfiles {
 
 		}
 	}
+	Nfsync::semclean();
 
 
 } # End of UpgradeProfiles
@@ -632,6 +639,7 @@ eval {
 	require RRDs; 			import RRDs;
 	require Mail::Header;	import Mail::Header;
 	require Mail::Internet;	import Mail::Internet;
+	require Socket6;		import Socket6;
 };
 if ( $@ ) {
 	print "Failed\nRequired nfsen modules not found\n";
