@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: Lookup.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: Lookup.pm 27 2011-12-29 12:53:29Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 27 $
 
 package Lookup;
 
@@ -39,6 +39,9 @@ use strict;
 use warnings;
 use Socket;
 use IO::Socket::INET;
+use Socket;
+use Socket6;
+use AbuseWhois;
 use Log;
 
 sub Lookup {
@@ -71,38 +74,9 @@ sub Lookup {
 		$port = 0;
 	} 
 
-	my $ipaddr = inet_aton($ip);
-	my $hostname = gethostbyaddr($ipaddr, AF_INET);
-
-	print $socket "<h3>$ip: $hostname</h3>\n";
 #   print $socket "Port: $port<br>";
 
-	my $whois_socket = IO::Socket::INET->new(
-		PeerAddr  => 'whois.cyberabuse.org',
-		PeerPort  => 43,
-		Proto	  => 'tcp',
-		timeout	  => 10 );
-
-	if ( !$whois_socket ) {
-		 print $socket "Can't connect to whoisd: $@<br>\n";
-		return;
-	}
-	
-	print $whois_socket "$ip\n";
-	print $socket "<pre>";
-	while ( <$whois_socket> ) {
-		chomp;
-		next if $_ =~ /^%/;
-		next if $_ =~ /^\[/;
-		next if $_ =~ /^$/;
-		$_ =~ s/^\s*(.+)/$1/;
-		$_ =~ s/:\s+/ /;
-		next if $_ =~ /^Source/;
-		print $socket "$_\n";
-	}
-
-	close $whois_socket;
-	print $socket "</table>";
+	AbuseWhois::Query($socket, $ip);
 
 } # End of Lookup
 
