@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: NfConf.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: NfConf.pm 37 2012-01-14 11:28:25Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 37 $
 
 package NfConf;
 
@@ -66,6 +66,7 @@ our $low_water;
 our $syslog_facility;
 our $ZIPcollected;
 our $ZIPprofiles;
+our $InterruptExpire;
 our $EXTENSIONS;
 our $PIDDIR;
 our $FILTERDIR;
@@ -76,7 +77,8 @@ our $SIMmode;
 our $Refresh;
 our $BACKEND_PLUGINDIR;
 our $PICDIR;
-
+our $NFPROFILEOPTS;
+our $NFEXPIREOPTS;
 
 # Alerting email vars
 our $MAIL_FROM;
@@ -88,6 +90,8 @@ our $UID;
 our $GID;
 our $LogSocket;
 
+our $CYCLETIME;
+
 #
 # Loads the config from nfsen.conf file
 # returns 1 on success. 
@@ -102,6 +106,7 @@ sub LoadConfig {
 	}
 	
 	# preset default values:
+	$CYCLETIME		 = 300;
 	$DEBUG			 = 0;
 	$BASEDIR		 = undef;
 	$BINDIR			 = undef;
@@ -141,8 +146,12 @@ sub LoadConfig {
 	$MAIL_BODY		 = q{Alert '@alert@' triggered at timeslot @timeslot@};
 	$SMTP_SERVER	 = '';
 
-	$ZIPcollected	 = 0;
-	$ZIPprofiles	 = 0;
+	$ZIPcollected	 = 1;
+	$ZIPprofiles	 = 1;
+	$InterruptExpire = 0;
+
+	$NFPROFILEOPTS	 = '';
+	$NFEXPIREOPTS	 = '';
 
 	my $log_type 	= $^V =~ /5.10/ ? 'native' : 'unix';
 
@@ -216,9 +225,6 @@ sub LoadConfig {
 	}
 	$GID = $gid;
 
-	$ZIPcollected = $ZIPcollected == 0 ? '' : '-z';
-	$ZIPprofiles  = $ZIPprofiles == 0 ? '' : '-z';
-
 
 	$Log::ERROR = undef ;
 	return 1;
