@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: NfSen.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: NfSen.pm 28 2011-12-30 11:43:56Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 28 $
 
 package NfSen;
 
@@ -52,23 +52,33 @@ our $hints;
 sub ValidFilename {
 	my $filename = shift;
 
-	if ( $filename =~ m#[/\s:;|]# ) {
-		return "Name must not contain any '/' ';', ':', '|'";
+	if ( $filename !~ /[A-Za-z0-9\-,_]/ ) {
+ 		return "Invalid name: RRD allowed characters: A-Z, a-z, 0-9, -,_ "
 	}
+
+# RRD vname is limited to to chars above.
+#	if ( $filename =~ m#[/\\\s:"*?<>;|]# ) {
+#		return "Name must not contain any '/' ';', ':', '|'";
+#	}
 	if ( $filename =~ m#^\.# ) {
 		return "Name must not start with '.'";
 	}
-	if ( -e "/tmp/$filename" ) {
-		return "ok";
-	}
-	sysopen(TMP, "/tmp/filename", O_RDWR|O_CREAT|O_EXCL) or return "$!";
-	close TMP;
-	unlink "/tmp/filename";
 
 	return "ok"
 
 } # End of ValidFilename
 
+sub ValidEmail($) {
+    my $email = shift;
+
+    if ( $email =~ /^[a-z0-9_\.-]+\@([a-z0-9_-]+\.){1,}[a-z]{2,4}$/i ||
+        $email =~ /^[a-z0-9_\.-]+\@localhost$/i ) {
+        return 1;
+    } else {
+        return 0;
+    }
+} # End of ValidEmail
+
 #
 # Parse Expire string:
 # Valid format:
