@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: NfSenRC.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: NfSenRC.pm 45 2012-01-16 19:38:43Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 45 $
 
 package NfSenRC;
 
@@ -54,22 +54,21 @@ sub StartCollector {
 		print "[no collector]";
 		return;
 	}
-
 	my @SourceList;
 	my $type = undef;
 	foreach my $source ( sort keys %NfConf::sources ) {
 		my $_port = $NfConf::sources{$source}{'port'};
 		if ( $_port == $port ) {
 			push @SourceList, $source;
-		}
-		my $_type = exists $NfConf::sources{$source}{'type'} ? $NfConf::sources{$source}{'type'}: 'netflow';
-		if ( defined $type ) {
-			if ( $type ne $_type ) {
-				print "Can not start different type '$type' and '$_type' on same port!\n";
-				return;
+			my $_type = exists $NfConf::sources{$source}{'type'} ? $NfConf::sources{$source}{'type'}: 'netflow';
+			if ( defined $type ) {
+				if ( $type ne $_type ) {
+					print "Can not start different type '$type' and '$_type' on same port!\n";
+					return;
+				}
+			} else {
+				$type = $_type;
 			}
-		} else {
-			$type = $_type;
 		}
 	}
 
@@ -93,7 +92,8 @@ sub StartCollector {
 		return;
 	}
 
-	my $common_args = "-w -D -p $port -u $uid -g $gid $buffer_opts $subdirlayout -P $pidfile $NfConf::ZIPcollected $extensions";
+	my $ziparg = $NfConf::ZIPcollected ? '-z' : '';
+	my $common_args = "-w -D -p $port -u $uid -g $gid $buffer_opts $subdirlayout -P $pidfile $ziparg $extensions";
 	my $src_args;
 	my $optargs = '';
 	if ( scalar @SourceList > 1 ) {
