@@ -1,4 +1,4 @@
-#!%%PERL%%
+#!/usr/bin/perl
 #
 #  Copyright (c) 2004, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
 #  All rights reserved.
@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: Nfcomm.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: Nfcomm.pm 36 2012-01-14 10:13:53Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 36 $
 package Nfcomm;
 
 use strict;
@@ -44,7 +44,8 @@ use POSIX 'strftime';
 use POSIX 'setsid';
 use POSIX ":sys_wait_h";
 use Sys::Syslog;
-use UNIVERSAL qw( can );
+use Nfsync;
+use UNIVERSAL;
 
 use Log;
 use NfProfile;
@@ -165,13 +166,9 @@ sub GetGlobals {
 	my ($offhour, $offmin) = strftime('%z', localtime) =~ /^(.\d{2})(\d{2})/;
 	$GMToffset 		= $offhour * 3600 + $offmin * 60;
 
-#	print $socket "\$DOCURL	 = \"/nfsen/doc\";\n";
-	print $socket "_globals=\$PROFILEDATADIR = \"$NfConf::PROFILEDATADIR\";\n";
 	print $socket "_globals=\$SUBDIRLAYOUT = \"$NfConf::SUBDIRLAYOUT\";\n";
 	print $socket "_globals=\$FRONTEND_PLUGINDIR = \"$NfConf::FRONTEND_PLUGINDIR\";\n";
 	print $socket "_globals=\$RRDoffset = \"$NfConf::RRDoffset\";\n";
-#	print $socket "_globals=\$DEBUG = \"$NfConf::DEBUG\";\n";
-#	print $socket "\$LIBEXECDIR = \"$NfConf::LIBEXECDIR\";\n";
 
 	print $socket "_globals=\$Refresh = \"$NfConf::Refresh\";\n";
 	print $socket "_globals=\$GMToffset = $GMToffset;\n";
@@ -188,10 +185,10 @@ sub SemCheck {
 	my $socket  = shift;
 	my $opts	= shift;
 
-	print $socket ". Semaphore $main::semlock\n";
+	print $socket ". Semaphore Nfsync::semlock\n";
 	print $socket $EODATA;
-	if ( main::semnowait($main::semlock) ) {
-		main::semsignal($main::semlock);
+	if ( Nfsync::semnowait() ) {
+		Nfsync::semsignal();
 		print $socket "OK Semaphore available\n";
 	} else {
 		print $socket "ERR Semaphore not available\n";
@@ -801,6 +798,7 @@ sub Setup_Server {
 			close $server;
 			return undef;
 		}
+		chown $NfConf::UID, $NfConf::GID, $socket_path; 
 		chmod 0660, $socket_path;
 
 	} else {
@@ -857,7 +855,7 @@ sub spawn {
 		return; # I'm the parent
 	}
 	# else I'm the child -- go spawn
-print STDERR "Spawn new process\n";
+
 	open(STDIN,  "<&Client")   || die "can't dup client to stdin";
 	open(STDOUT, ">&Client")   || die "can't dup client to stdout";
 	## open(STDERR, ">&STDOUT") || die "can't dup stdout to stderr";
